########################################################################################################################################################################
# SCRIPT for: Mobility-driven α- and β-diversity patterns in plants, microbes and insects create different communities across elevation gradients in subarctic regions #
########################################################################################################################################################################

# Libraries: ####
library(dplyr)
library(tidyr)
library(stringr)
library(lubridate)
library(readr)
library(hms)
library(ggplot2)
library(ggrepel)
library(pipeR)
library(rlist)
library(purrr)
library(ggpubr)
library(scales)
library(chron)
library(gsubfn)
library(stringi)
library(slider)
library(tidyquant)
library(tidyverse)
library(zoo)
library(GGally)
library(psych)
library(psychTools)
library(GPArotation)
library(corrplot)
library(betapart)
library(vegan)
library(glmmTMB)
library(DHARMa)
library(effects)
library(performance)
library(MuMIn)
library(forcats)
library(gridExtra)
library(correlation)
library("ggExtra")
library("ggvenn")
library("ggVennDiagram")
library(VennDiagram)
library(ComplexUpset)
library(lavaan)
library(semPlot)
library(piecewiseSEM)
library(nlme)
library(DiagrammeR)
library(car)
library(patchwork)
library(ggeffects)
library(textreg)
library(jtools)
library(NADA2)
library(geosphere)
library(Matrix)
library("RColorBrewer")
library(hrbrthemes)
library(eulerr)

species_vk_mal<- read.csv("//storage.slu.se/Home$/pode0001/Desktop/MANUSCRIPTS/Paper3/Submission/Final/Script and Data Availability/m20_21_vk_matrix.csv", sep=";") # Fungi

############################################################################
# γ-Diversity: SHARED vs COMMON TAXONOMIC RICHNESS IN KILPISJARVI/VARANGER #
############################################################################
#### FIGURE 1: To characterise γ-diversity as well as general differences in species richness and composition between the two regions, we calculated the overall taxonomic richness and the proportion of taxa shared among regions for each organism group.

# Importing datasets:
malaise<- read.csv("//path-to-data/malaise_matrix.csv", sep=";") # Malaise
pitfall<- read.csv("//path-to-data/pitfall_matrix.csv", sep=";") # Pitfall
plants<- read.csv("//path-to-data/plants_matrix.csv", sep=";") # Plants
fungi<- read.csv("/path-to-data/fungal_matrix.csv", sep=";") # Fungi

# Defining sampling sites:
PlotCodesV <- paste(c("V"), sprintf("%02d", c(1:20)), sep = "") # Sampling plots Varanger
PlotCodesK <- paste(c("K"), sprintf("%02d", c(1:35)), sep = "") # Sampling plots Kilpisjarvi
# Defining Jaccard Similarity function:
jaccard <- function(a, b) {
  intersection = length(intersect(a, b))
  union = length(a) + length(b) - intersection
  return (intersection/union)
}

# PRODUCING RESULTS FOR FIGURE 1:
### MALAISE COMMUNITIES ####
species_k_mal <- malaise %>%
  dplyr::filter(trapvk %in% c(PlotCodesK)) %>%
  select(where(~ any(. != 0)))

sp_k_mal_all<-unique(colnames(species_k_mal)[-1]) # 2013 species

species_v_mal <- malaise %>%
  dplyr::filter(trapvk %in% c(PlotCodesV)) %>%
  select(where(~ any(. != 0)))
sp_v_mal_all<-unique(colnames(species_v_mal)[-1]) # 1518 species

# Find Jaccard Similarity between the two sets 
Jsim<-jaccard(sp_v_mal_all, sp_k_mal_all) # 52.2 % Similarity
# Use list as input
vk_mal_all <-list('V'=sp_v_mal_all,'K'=sp_k_mal_all)

# Plot Euler diagram - Malaise ####
fit <- euler(vk_mal_all)
ggvenn_vk_mal <-
  plot(
    fit,
    fill = "Orange",
    lty = "de",
    counts = T,
    cex = 5,
    quantities = T
  )
### PITFALL COMMUNITIES ####
species_k_pit <- pitfall %>%
  dplyr::filter(trapvk %in% c(PlotCodesK)) %>%
  select(where(~ any(. != 0)))

sp_k_pit_all<-unique(colnames(species_k_pit)[-1]) # 2013 species

species_v_pit <- pitfall %>%
  dplyr::filter(trapvk %in% c(PlotCodesV)) %>%
  select(where(~ any(. != 0)))
sp_v_pit_all<-unique(colnames(species_v_pit)[-1]) # 1518 species

# Find Jaccard Similarity between the two sets 
Jsim<-jaccard(sp_v_pit_all, sp_k_pit_all) # 52.2 % Similarity
# Use list as input
vk_pit_all <-list('V'=sp_v_pit_all,'K'=sp_k_pit_all)

# Plot Euler diagram - Pitfall ####
fit <- euler(vk_pit_all)
ggvenn_vk_pit <-
  plot(
    fit,
    fill = "Blue",
    lty = "de",
    counts = T,
    cex = 5,
    quantities = T
  )
### PLANT COMMUNITIES ####
species_k_pl <- plants %>%
  dplyr::filter(trapvk %in% c(PlotCodesK)) %>%
  select(where(~ any(. != 0)))

sp_k_pl_all<-unique(colnames(species_k_pl)[-1]) # 2013 species

species_v_pl <- plants %>%
  dplyr::filter(trapvk %in% c(PlotCodesV)) %>%
  select(where(~ any(. != 0)))
sp_v_pl_all<-unique(colnames(species_v_pl)[-1]) # 1518 species

# Find Jaccard Similarity between the two sets 
Jsim<-jaccard(sp_v_pl_all, sp_k_pl_all) # 52.2 % Similarity
# Use list as input
vk_pl_all <-list('V'=sp_v_pl_all,'K'=sp_k_pl_all)

# Plot Euler diagram - Plants ####
fit <- euler(vk_pl_all)
ggvenn_vk_pl <-
  plot(
    fit,
    fill = "Yellow",
    lty = "de",
    counts = T,
    cex = 5,
    quantities = T
  )

### FUNGAL COMMUNITIES ####
species_k_f <- fungi %>%
  dplyr::filter(trapvk %in% c(PlotCodesK)) %>%
  select(where(~ any(. != 0)))

sp_k_f_all<-unique(colnames(species_k_f)[-1]) # 2013 species

species_v_f <- fungi %>%
  dplyr::filter(trapvk %in% c(PlotCodesV)) %>%
  select(where(~ any(. != 0)))
sp_v_f_all<-unique(colnames(species_v_f)[-1]) # 1518 species

# Find Jaccard Similarity between the two sets 
Jsim<-jaccard(sp_v_f_all, sp_k_f_all) # 52.2 % Similarity
# Use list as input
vk_f_all <-list('V'=sp_v_f_all,'K'=sp_k_f_all)

# Plot Euler diagram - Fungi ####
fit <- euler(vk_f_all)
ggvenn_vk_f <-
  plot(
    fit,
    fill = "Purple",
    lty = "de",
    counts = T,
    cex = 5,
    quantities = T
  )

### TOTAL VENN DIAGRAMS ####
gvenn<-ggarrange(
  ggvenn_vk_mal,
  ggvenn_vk_pit,
  ggvenn_vk_pl,
  ggvenn_vk_f,
  nrow = 2, ncol = 2,
  common.legend = FALSE
)





#### ------------------------------------------------------------------- ####

#####################################################################
# γ-Diversity: NDMS PLOTS FOR EACH TAXA IN KILPISJARVI AND VARANGER #
#####################################################################
#### FIGURE 2: To characterise differences in community compositions, we used non-metric multidimensional scaling (NMDS) as fitted to two dimensions using a Jaccard distance matrix

# Importing datasets:
malaise<- read.csv("//path-to-data/malaise_matrix.csv", sep=";") # Malaise
pitfall<- read.csv("//path-to-data/pitfall_matrix.csv", sep=";") # Pitfall
plants<- read.csv("//path-to-data/plants_matrix.csv", sep=";") # Plants
fungi<- read.csv("/path-to-data/fungal_matrix.csv", sep=";") # Fungi

### MALAISE COMMUNITIES ####
malaise <-
  malaise %>%
  mutate(SamplingSite = ifelse(grepl('K', malaise$trapvk), 'Kilpisjarvi', 'Varanger'),
         .after = "trapvk")

ordi_nmds <- metaMDS(malaise[,3:length(malaise)], trymax=999, distance="jaccard") 
stressplot(ordi_nmds) # R2= 0.915
nmds_points <- as.data.frame(ordi_nmds$points)
groups <-malaise$SamplingSite
nmds_sp <- as.data.frame(ordi_nmds$species[,1:2])

# Plot NDMS Malaise
malaise_ndmsplot <- ggplot(data = nmds_points, 
                           (aes(x = nmds_points[, 1], y = nmds_points[, 2], colour = groups))) +
  geom_point(size = 3) +
  theme_classic() +
  guides(colour = guide_legend(override.aes = list(size = 3))) +
  stat_ellipse() +
  xlab(" ") +
  ylab(" ") +
  scale_x_continuous(limits = c(-2, 2.5), n.breaks = 5) +
  scale_y_continuous(limits = c(-2, 1.5), n.breaks = 5) +
  ggtitle(paste0("Malaise; Stress=", round(ordi_nmds$stress, 2))) +
  theme(text = element_text(size = 20)) +
  scale_color_manual(values = c('#fdbf6f', "#80b1d3"))

### PITFALL COMMUNITIES ####
pitfall <-
  pitfall %>%
  mutate(SamplingSite = ifelse(grepl('K', pitfall$trapvk), 'Kilpisjarvi', 'Varanger'),
         .after = "trapvk")

ordi_nmds <- metaMDS(pitfall[,3:length(pitfall)], trymax=999, distance="jaccard") 
stressplot(ordi_nmds) # R2=0.826
nmds_points <- as.data.frame(ordi_nmds$points)
groups <-pitfall$SamplingSite
nmds_sp <- as.data.frame(ordi_nmds$species[,1:2])

# Plot NDMS Pitfall
pitfall_nmdsplot <- ggplot(data = nmds_points,
                           (aes(x = nmds_points[, 1], y = nmds_points[, 2], colour = group))) +
  geom_point(size = 3) +
  ggtitle(paste0("Pitfall; Stress=", round(ordi_nmds$stress, 2))) +
  theme_classic() +
  guides(colour = guide_legend(override.aes = list(size = 3))) +
  stat_ellipse() +
  xlab(" ") +
  ylab(" ") +
  scale_x_continuous(limits = c(-2, 2.5), n.breaks = 5) +
  scale_y_continuous(limits = c(-2, 1.5), n.breaks = 5) +
  theme(text = element_text(size = 20)) +
  scale_color_manual(values = c('#fdbf6f', "#80b1d3"))

### PLANT COMMUNITIES ####
plants <-
  plants %>%
  mutate(SamplingSite = ifelse(grepl('K', plants$trapvk), 'Kilpisjarvi', 'Varanger'),
         .after = "trapvk")

ordi_nmds <- metaMDS(plants[,3:length(plants)], trymax=100, distance="jaccard") 
stressplot(ordi_nmds) #R2=0.933
nmds_points <- as.data.frame(ordi_nmds$points)
groups <-plants$SamplingSite
nmds_sp <- as.data.frame(ordi_nmds$species[,1:2])

# Plot NDMS Plants
plants_nmdsplot <- ggplot(data=nmds_points, 
                          (aes(x=nmds_points[,1], y=nmds_points[,2], colour = groups))) +
  geom_point(size=3) + 
  ggtitle(paste0("Plant; Stress=",round(ordi_nmds$stress,2)))+
  theme_classic() + 
  guides(colour = guide_legend(override.aes = list(size=3))) +
  stat_ellipse() + 
  xlab(" ") + 
  ylab(" ") + 
  scale_x_continuous(limits = c(-2, 2.5),n.breaks = 5) +
  scale_y_continuous(limits = c(-2, 1.5),n.breaks = 5) +
  theme(text = element_text(size = 20))+
  scale_color_manual(values = c('#fdbf6f',"#80b1d3"))

### FUNGI COMMUNITIES ####
fungi <-
  fungi %>%
  mutate(SamplingSite = ifelse(grepl('K', fungi$trapvk), 'Kilpisjarvi', 'Varanger'),
         .after = "trapvk")

ordi_nmds <- metaMDS(fungi[,3:length(fungi)], k=2, trymax=999, distance="jaccard") 
stressplot(ordi_nmds) #R2= 0.9
str(ordi_nmds)
nmds_points <- as.data.frame(ordi_nmds$points)
groups <-fungi$SamplingSite
nmds_sp <- as.data.frame(ordi_nmds$species[,1:2])

# Plot NDMS Fungi
fungi_nmdsplot <- ggplot(data = nmds_points, (aes(
  x = nmds_points[, 1], y = nmds_points[, 2], colour = groups))) +
  geom_point(size = 3) +
  ggtitle(paste0("Fungi; Stress=", round(ordi_nmds$stress, 2))) +
  theme_classic() +
  guides(colour = guide_legend(override.aes = list(size = 3))) +
  stat_ellipse() +
  xlab(" ") +
  ylab(" ") +
  scale_x_continuous(limits = c(-2, 2.5), n.breaks = 5) +
  scale_y_continuous(limits = c(-2, 1.5), n.breaks = 5) +
  theme(text = element_text(size = 20)) +
  scale_color_manual(values = c('#fdbf6f', "#80b1d3"))

### TOTAL NMDS PLOTS ####
ggnmds<-ggarrange(
  malaise_nmdsplot,
  pitfall_nmdsplot,
  plants_nmdsplot,
  fungi_nmdsplot,
  nrow = 2, ncol = 2,
  common.legend = T
)


#### ------------------------------------------------------------------- ####

#####################################################################
# α-Diversity: CORRELATIONS BETWEEN TAXA - KILPISJARVI AND VARANGER #
#####################################################################
#### FIGURE 3: To assess the level of congruence in patterns of α-diversity across sessile versus mobile taxa we used Pearson moment product correlations.

# Importing datasets:
total_sp<- read.csv("//path-to-data/species_richness.csv", sep=";") # Sp.Richness
total_sp_k <- species_richness [-c(36:55),] # Sp.Richness Kilpisjarvi
total_sp_v <- species_richness [c(36:55),] # Sp.Richness Varanger

# Correlation plots ####
cormat.k<-total_sp_k %>% select(3,4,5,2)
cormat.v<-total_sp_v %>% select(3,4,5,2)

cormat.k_log<- log(cormat.k)
cormat.v_log<- log(cormat.v)

cork_log<-cor(cormat.k_log, method = "pearson")
p.matk_log <- cor.mtest(cormat.k_log)

corv_log<-cor(cormat.v_log, method = "pearson")
p.matv_log <- cor.mtest(cormat.v_log)

corkplot <-
  corrplot(
    cork_log,
    method = "color",
    addCoef.col = "black",
    type =  "lower",
    tl.col="black",
    tl.srt= 45,
    order = "original",
    p.mat = p.matk_log$p,
    insig = "pch"
  )

corvplot <-
  corrplot(
    corv_log,
    method = "color",
    addCoef.col = "black",
    type =  "lower",
    tl.col="black",
    tl.srt= 45,
    order = "original",
    p.mat = p.matv_log$p,
    insig = "pch"
  )


#### ------------------------------------------------------------------- ####

########################################################################
# α-Diversity: Sp.Richness ~ REGION * TAXON * ELEVATION + (1|PLOTCODE) #
########################################################################
#### FIGURE 4: We compared patterns of local taxonomic richness between organism groups (i.e. TrapType), regions (i.e SamplingSite), and along the elevational gradients (i.e Elevation) using a generalized linear mixed model. Organism group, region, elevation and all two- and three-way interactions were included as fixed effects and since multiple organism groups had been measured within each sampling site, we included sampling plot (i.e PlotCode) as a random effect.

# Importing dataset:
model_data <- read.csv("//path-to-data/alpha_model.csv", sep=";")

# Assesing distribution of the response variable ####

## Create a list of all unique TrapTypes and Sampling sites
trap_types <- unique(model_data$TrapType)
sampling_sites <- unique(model_data$SamplingSite)

## Create a function to generate density plots for a given combination
generate_densplot <- function(trap_type, sampling_site) {
  df_filtered <- model_data %>%
    filter(TrapType == trap_type, SamplingSite == sampling_site)
  
  ggplot(df_filtered, aes(x = Richness)) +
    geom_density(color = "blue",
                 fill = "red",
                 alpha = 0.5) +
    geom_point(aes(x = Richness, y = 0), alpha = 0.5) +
    labs(title = paste(trap_type, sampling_site), x = "Species Richness", y = "Frequency")
}

## Create a list to store the density plots
densplots <- list()

## Generate density plots for all combinations
for (trap_type in trap_types) {
  for (sampling_site in sampling_sites) {
    plot_title <- paste(trap_type, sampling_site)
    densplots[[plot_title]] <- generate_densplot(trap_type, sampling_site)
  }
}

## Arrange and display the density plots
library(gridExtra)
grid.arrange(grobs = densplots, ncol = length(sampling_sites))

# Models with and without three-way interaction ####
modelwithout <- glmmTMB(
  Richness ~ SamplingSite + TrapType + Elevation +
    SamplingSite * TrapType +
    SamplingSite * Elevation +
    TrapType * Elevation +
    (1|PlotCode),
  data = model_data,
  family = nbinom2()
)
modelwith <- glmmTMB(
  Richness ~ SamplingSite + TrapType + Elevation +
    SamplingSite * TrapType +
    SamplingSite * Elevation +
    TrapType * Elevation +
    SamplingSite * TrapType * Elevation +
    (1|PlotCode),
  data = model_data,
  family = nbinom2()
)
anova(modelwithout,modelwith)

# Full Model: Richness ~ SamplingSite * TrapType * Elevation + (1|PlotCode) ####
full.model <- glmmTMB(
  Richness ~ SamplingSite * TrapType * Elevation + (1|PlotCode),
  data = model_data,
  family = nbinom2()
)
summary(full.model)

# Plot with raw values and prediction based on the model using geom_smooth
model_data$pred = predict(full.model)

Altitude_SpRich <-
  ggplot(model_data, aes(Elevation, y = log(Richness), color = TrapType)) +
  geom_point(size = 2.5) +
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_smooth(
    data = subset(model_data, SamplingSite == "Kilpisjarvi"),
    aes(y = pred, group = TrapType, color = TrapType),
    method = "glm", alpha = .15, se = T
  ) +
  geom_smooth(
    data = subset(model_data, SamplingSite == "Varanger"),
    aes(y = pred, group = TrapType, color = TrapType),
    method= "glm",  alpha = .15, se = T
  ) + theme_light() +
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_text(size = 16, colour = "black"),
        legend.position = "none",
        panel.border = element_blank(),
        axis.line = element_line(colour = "darkgrey")) + 
  xlab(expression("Elevation (m)")) +
  ylab(expression(Log ~ (alpha ~ -Diversity))) 

# Model validation ####
Anova(full.model, type = "III")
summary(full.model)

simulationOutput <- simulateResiduals(fittedModel = full.model, plot = F, n = 2000)
residuals(simulationOutput)
#### FIGURE S4: DHARMa residual diagnostics. On the left, we show quantile-quantile plot with added tests for correct distribution (KS test), dispersion and outliers. On the right, we show DHARMa-simulated residuals vs model predictions.
plot(simulationOutput)

par(mfrow = c(1,3))
plotResiduals(simulationOutput, form = model_data$SamplingSite)
plotResiduals(simulationOutput, form = model_data$TrapType)
plotResiduals(simulationOutput, form = model_data$Elevation)

testUniformity(simulationOutput)
testOutliers(simulationOutput)
testDispersion(simulationOutput) 
testQuantiles(simulationOutput) 

#### ------------------------------------------------------------------- ####

################################################################################
# β-diversity: β-component ~ REGION * TAXON * SPATIAL/ELEV DIFF + (1|PLOTPAIR) #
################################################################################
#### FIGURE 6: We modelled each pairwise β-diversity component as a separate, univariate function of either distance in space or elevational difference (with separate models for the two relations). We applied generalized linear mixed models where we logit-transformed the β-diversity measures to achieve approximate normality of residuals. Thus, we used linear regression assuming an identity link and Gaussian errors to model each logit-transformed β-diversity component as a function of organism group (Taxon), region (SamplingSite) and the euclidean distance (Spatial_Dist) or the difference in elevation (Alt_Dist) while including all two- and three-way interactions. As with α-diversity, we included sampling plot (PlotPair) as a random effect since different organism groups were measured within each sampling site.

# Importing dataset:
VK_total <- read.csv("//path-to-data/beta_model.csv", sep=",")
VK_total <- VK_total[,-1]

# Checking distribution of β-components and Spatial and Elevational distance ####
names(VK_total[, c(4:8)])
betakv <- VK_total[, c(4:8)] %>% keep(is.numeric) %>%
  gather() %>%
  mutate(name = fct_relevel(key, names(VK_total[, c(4:8)]))) %>%
  ggplot(aes(value)) +
  facet_wrap(~ name, nrow = 2, scales = "free") +
  labs(title = "BetaDiversity Kilpisjarvi and Varanger",
       y = "density",
       x = "values") +
  geom_density(color = "blue",
               fill = "red",
               alpha = 0.5) +
  geom_point(aes(x = value, y = 0), alpha = 0.5)

# Based on the distribution of Turnover, Nestedness and Beta total:
#  - We transformed them using the logit formula:logit(Y) = log(Y/(1-Y))
#  - The distribution of response variables seems to be good now! 
#  - However, there are 0s in the data so we need to transform them.
#     > Number of 0s in Turnover and Nestedness and transformation to avoid -Inf
#         colSums(VK_total[,4:6]==0) # Number of 0s
#     
#     > Turnover:
#         sort(unique(VK_total$Turnover))[1:5] 
#         log(0.1176471/(1-0.1176471)) # -2.014903
#         Chosen transformation closest to minimum value that is not 0: 0.1
#         log(0.1/(1-0.1)) # -2.197225
#
#     >Nestedness:
#         sort(unique(VK_total$Nestedness))[1:5]  
#         log(0.0002749009/(1-0.0002749009)) # -8.198825
#         Chosen transformation closest to minimum value that is not 0: 0.0001
#         log(0.0001/(1-0.0001)) # -9.21024

VK_total_trans <- VK_total %>%
  mutate(across(Turnover, ~ replace(., . ==  0 , 0.1))) %>%
  mutate(across(Nestedness, ~ replace(., . ==  0 , 0.0001))) %>%
  mutate(Turnover_logit = log(Turnover/(1-Turnover)),
         Nestedness_logit = log(Nestedness/(1-Nestedness)),
         Btotal_logit = log(Btot/(1-Btot)))

# Comparison of transformed vs not transformed β-components
betakv <- VK_total_trans[, c(4:6, 11:13)] %>% keep(is.numeric) %>%
  gather() %>%
  mutate(name = fct_relevel(key, names(VK_total_trans[, c(4:6, 11:13)]))) %>%
  ggplot(aes(value)) +
  facet_wrap(~ name, nrow = 2, scales = "free") +
  labs(title = "BetaDiversity Kilpisjarvi and Varanger",
       y = "density",
       x = "values") +
  geom_density(color = "blue",
               fill = "red",
               alpha = 0.5) +
  geom_point(aes(x = value, y = 0), alpha = 0.5)

# Models of the different β-components using Elevational difference: ####
#   Turnover ~ Region * Taxon * Elevational Diff + (1|PlotPair) 
#   Nestedness ~ Region * Taxon * Elevational Diff + (1|PlotPair) 
#   Total Betadiversity ~ Region * Taxon * Elevational Diff + (1|PlotPair) 

Jtur_Alt_m <- glmmTMB(
  Turnover_logit ~ SamplingSite * Taxon * Alt_Dist + (1|PlotPair),
  data = VK_total_trans,
  family = gaussian()
)
summary(Jtur_Alt_m)

Jnes_Alt_m <- glmmTMB(
  Nestedness_logit ~ SamplingSite * Taxon * Alt_Dist + (1|PlotPair) ,
  data = VK_total_trans,
  family = gaussian()
)
summary(Jnes_Alt_m)

Jtot_Alt_m <- glmmTMB(
  Btotal_logit ~ SamplingSite * Taxon * Alt_Dist + (1|PlotPair),
  data = VK_total_trans,
  family = gaussian()
)
summary(Jtot_Alt_m)

# Models of the different β-components using Spatial distance: ####
#   Turnover ~ Region * Taxon * Spatial Dist + (1|PlotPair) 
#   Nestedness ~ Region * Taxon * Spatial Dist + (1|PlotPair) 
#   Total Betadiversity ~ Region * Taxon * Spatial Dist + (1|PlotPair) 

Jtur_Spatial_m <- glmmTMB(
  Turnover_logit ~ SamplingSite * Taxon * Spatial_Dist + (1|PlotPair),
  data = VK_total_trans,
  family = gaussian()
)
summary(Jtur_Spatial_m)

Jnes_Spatial_m <- glmmTMB(
  Nestedness_logit ~ SamplingSite * Taxon * Spatial_Dist + (1|PlotPair) ,
  data = VK_total_trans,
  family = gaussian()
)
summary(Jnes_Spatial_m)

Jtot_Spatial_m <- glmmTMB(
  Btotal_logit ~ SamplingSite * Taxon * Spatial_Dist + (1|PlotPair),
  data = VK_total_trans,
  family = gaussian()
)
summary(Jtot_Spatial_m)

# Validation of models of β-components using Elevational/Spatial difference ####

# Function to automate the process
simulate_and_plot <- function(model, data, n = 1000) {
  # Simulating residuals
  simulationOutput <- simulateResiduals(fittedModel = model, n = n)
  
  # Plotting residuals
  plot(simulationOutput, asFactor = TRUE)
  
  par(mfrow = c(1, 4))
  plotResiduals(simulationOutput, form = data$SamplingSite)
  plotResiduals(simulationOutput, form = data$Taxon)
  plotResiduals(simulationOutput, form = data$Alt_Dist)
  plotResiduals(simulationOutput, form = data$Spatial_Dist)
  
  # Tests and diagnostics
  par(mfrow = c(1, 3))
  testUniformity(simulationOutput)
  testOutliers(simulationOutput)
  testDispersion(simulationOutput)
  
  diagnose(model)
  Anova(model, type = "III")
}

# Models of the different β-components using Elevational difference - validation
simulate_and_plot(Jtur_Alt_m, VK_total_trans)
simulate_and_plot(Jnes_Alt_m, VK_total_trans)
simulate_and_plot(Jtot_Alt_m, VK_total_trans)

# Models of the different β-components using Spatial distance - validation
simulate_and_plot(Jtur_Spatial_m, VK_total_trans)
simulate_and_plot(Jnes_Spatial_m, VK_total_trans)
simulate_and_plot(Jtot_Spatial_m, VK_total_trans)

#### ------------------------------------------------------------------- ####

###########################################################################
# β-diversity: Statistical significance of each interaction term included #
###########################################################################
#### TABLE 1: We based our inference on a comparison of log-likelihoods of models including or excluding the interaction terms, starting from the three-way interaction taxon×region×elevation. Nonetheless, for β-diversity, we note that data points are not independent of each other, because each data point in the linear model involves a pair of samples that are correlated in space. For this reason, we did not perform tests based on output from the linear model, but instead employed a series of permutation tests, of which each was designed to examine the significance of a particular interaction term. We first calculated the log-likelihood ratio between the model where the focal interaction was included (full model), and the model from which the focal interaction was excluded (reduced model). We then compared the observed log-likelihood ratio to its null distribution, which we computed by permuting the data N=1.000 times. If the log-likelihood ratio for the full vs. reduced model fitted to the actual data was greater than the log-likelihood ratio for the full vs. reduced model fitted to the permuted data for at least 95% of the permutation outcomes, the explanatory variable was deemed significant.

# Importing dataset:
VK_total <- read.csv("//path-to-data/beta_models.csv", sep=",")
data <- VK_total[,-1] %>%
  mutate(across(Turnover, ~ replace(., . ==  0 , 0.1))) %>%
  mutate(across(Nestedness, ~ replace(., . ==  0 , 0.0001))) %>%
  mutate(Turnover_logit = log(Turnover/(1-Turnover)),
         Nestedness_logit = log(Nestedness/(1-Nestedness)),
         Btotal_logit = log(Btot/(1-Btot)))

## Permutation functions for elevation and euclidean distances ####
# 1) If there was NO STRUCTURING with ELEVATION across TAXA:
# Then, the null model should be done by randomizing the difference in elevation 
# attributed to each sampling pair, within the same region 
# (i.e. not changing the region label for that sampling pair)

# Function to permute DIFFERENCE IN ELEVATION while keeping TAXON fixed
randomize_elevation <- function(data) {
  # Create a copy of the original dataset
  randomized_data <- data
  # Randomize elevation column across responses
  randomized_data$Alt_Dist <- sample(data$Alt_Dist)
  return(randomized_data)
}
randomization_results <- randomize_elevation(data)

# 2) If there was NO STRUCTURING with EUCLIDEAN DISTANCE across TAXA:
# Then, the null model should be done by randomizing the difference in spatial distance 
# attributed to each sampling pair, within the same region 
# (i.e. not changing the region label for that sampling pair)

# Function to permute EUCLIDEAN DISTANCE while keeping TAXON fixed
randomize_spatdist <- function(data) {
  # Create a copy of the original dataset
  randomized_data <- data
  # Randomize elevation column across responses
  randomized_data$Spatial_Dist <- sample(data$Spatial_Dist)
  return(randomized_data)
}
randomization_results <- randomize_spatdist(data)

# 3) If there was NO STRUCTURING with REGION across TAXA:
# Then, the null model should be done by randomizing the region 
# attributed to each sampling pair, within the same distance in elevation 
# (i.e. not changing the Δ elevation label for each sampling pair)

# Function to permute REGION while keeping TAXON fixed
randomize_region <- function(data) {
  # Create a copy of the original dataset
  randomized_data <- data
  # Randomize elevation column across responses
  randomized_data$SamplingSite <- sample(data$SamplingSite)
  return(randomized_data)
}
randomization_results <- randomize_region(data)

# 4) If there was NO STRUCTURING between REGION and ELEVATION:
# Then the null model should be done by 
# 1) randomizing the Δ elevation attributed to each sampling pair and 
# 2) randomizing the region attributed to each sampling pair 
# (for which a new Δ elevation has been attributed).
randomize_elev_region <- function(data) {
  # Create a copy of the original dataset
  randomized_data <- data
  # Randomize elevation column across responses
  randomized_data$Alt_Dist <- sample(data$Alt_Dist)
  # Randomize region column across responses
  randomized_data$SamplingSite <- sample(data$SamplingSite)
  
  return(randomized_data)
  #return(list(randomized_elevation = randomized_elevation, randomized_region = randomized_region))
}
randomization_results <- randomize_elev_region(data)

# 5) If there was NO STRUCTURING between REGION and EUCLIDEAN DISTANCE:
# Then the null model should be done by 
# 1) randomizing the euclidean distance attributed to each sampling pair and 
# 2) randomizing the region attributed to each sampling pair 
# (for which a new euclidean distance has been attributed).
randomize_spatdist_region <- function(data) {
  # Create a copy of the original dataset
  randomized_data <- data
  # Randomize elevation column across responses
  randomized_data$Spatial_Dist <- sample(data$Spatial_Dist)
  # Randomize region column across responses
  randomized_data$SamplingSite <- sample(data$SamplingSite)
  
  return(randomized_data)
  #return(list(randomized_elevation = randomized_elevation, randomized_region = randomized_region))
}
randomization_results <- randomize_spatdist_region(data)

# 6) If there was NO STRUCTURING between TAXA, REGION and DELTA ELEVATION, 
# Then the null model should be done by 
# 1) randomizing the taxa attributed to each value of betadiversity, 
# 2) randomizing the difference in elevation attributed to that sampling pair
# 3) finally attributing a random region to that sampling pair.
randomize_taxa_elev_region <- function(data) {
  # Create a copy of the original dataset
  randomized_data <- data
  # Randomize taxa column across responses
  randomized_data$Taxon <- sample(data$Taxon)
  # Randomize elevation column across responses
  randomized_data$Alt_Dist <- sample(data$Alt_Dist)
  # Randomize region column across responses
  randomized_data$SamplingSite <- sample(data$SamplingSite)
  
  return(randomized_data)
  #return(list(randomized_elevation = randomized_elevation, randomized_region = randomized_region))
}
randomization_results <- randomize_taxa_elev_region(data)

# 7) If there was NO STRUCTURING between TAXA, REGION and EUCLIDEAN DISTANCE, 
# Then the null model should be done by 
# 1) randomizing the taxa attributed to each value of betadiversity, 
# 2) randomizing the euclidean distance attributed to that sampling pair
# 3) finally attributing a random region to that sampling pair.
randomize_taxa_spatdist_region <- function(data) {
  # Create a copy of the original dataset
  randomized_data <- data
  # Randomize taxa column across responses
  randomized_data$Taxon <- sample(data$Taxon)
  # Randomize elevation column across responses
  randomized_data$Spatial_Dist <- sample(data$Spatial_Dist)
  # Randomize region column across responses
  randomized_data$SamplingSite <- sample(data$SamplingSite)
  
  return(randomized_data)
  #return(list(randomized_elevation = randomized_elevation, randomized_region = randomized_region))
}
randomization_results <- randomize_taxa_spatdist_region(data)

#### ------------------------------------------------------------------- ####

# Models including elevational differences - statistical significance
#### TABLE 1: Bottom part of table. 
# Statistical significance of each interaction term included in the β-diversity models using region, organism group and elevational differences as explanatory variables. Values at or below 0.05 are deemed significant

## TURNOVER ~ SamplingSite * Taxon * Alt_Dist + (1|PlotPair)  ####

# Testing 2-WAY interaction: TAXON x ELEVATION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Results table: 
results <- data.frame(Model = c(1:24), Results = c(1:24))
j=1
# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced turnover models randomizing Elevation only (TAXON x ELEVATION)
for (i in 1:num_permutations) {
  data_perm <- randomize_elevation(data)
  
  full.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite +
      Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot1ta <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Turnover model using Δ elevation, the interaction between TAXON and ELEVATION is", significance, "with a P-value =", p_value))
j = j+1



# Testing 2-WAY interaction: TAXON x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced turnover models randomizing Region only (TAXON x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_region(data)
  
  full.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite +
      Taxon:Alt_Dist + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot2ta <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Turnover model using Δ elevation, the interaction between TAXON and REGION is", significance, "with a P-value =", p_value))
j = j+1

# Testing 2-WAY interaction: ELEVATION x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced turnover models randomizing Elevation and Region (ELEVATION x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_elev_region(data)
  
  full.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot3ta <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Turnover model using Δ elevation, the interaction between ELEVATION and REGION is", significance, "with a P-value =", p_value))
j = j+1


# Testing 3-WAY interaction: TAXON x ELEVATION x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + Taxon:SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced turnover models randomizing Taxon, Elevation and Region (TAXON x ELEVATION x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_taxa_elev_region(data)
  
  full.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + Taxon:SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot4ta <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Turnover model using Δ elevation, the interaction between TAXON x ELEVATION x REGION is", significance, "with a P-value =", p_value))
j = j+1
#### ------------------------------------------------------------------- ####

## NESTEDNESS ~ SamplingSite * Taxon * Alt_Dist + (1|PlotPair)  ####

# Testing 2-WAY interaction: TAXON x ELEVATION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Nestedness models randomizing Elevation only (TAXON x ELEVATION)
for (i in 1:num_permutations) {
  data_perm <- randomize_elevation(data)
  
  full.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite +
      Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot1na <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Nestedness model using Δ elevation, the interaction between TAXON and ELEVATION is", significance, "with a P-value =", p_value))
j = j+1



# Testing 2-WAY interaction: TAXON x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Nestedness models randomizing Region only (TAXON x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_region(data)
  
  full.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite +
      Taxon:Alt_Dist + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot2na <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Nestedness model using Δ elevation, the interaction between TAXON and REGION is", significance, "with a P-value =", p_value))
j = j+1

# Testing 2-WAY interaction: ELEVATION x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Nestedness models randomizing Elevation and Region (ELEVATION x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_elev_region(data)
  
  full.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot3na <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Nestedness model using Δ elevation, the interaction between ELEVATION and REGION is", significance, "with a P-value =", p_value))
j = j+1


# Testing 3-WAY interaction: TAXON x ELEVATION x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + Taxon:SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Nestedness models randomizing Taxon, Elevation and Region (TAXON x ELEVATION x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_taxa_elev_region(data)
  
  full.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + Taxon:SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot4na <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Nestedness model using Δ elevation, the interaction between TAXON x ELEVATION x REGION is", significance, "with a P-value =", p_value))
j = j+1
#### ------------------------------------------------------------------- ####

## BETA TOTAL ~ SamplingSite * Taxon * Alt_Dist + (1|PlotPair)  ####

# Testing 2-WAY interaction: TAXON x ELEVATION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Total Betadiversity models randomizing Elevation only (TAXON x ELEVATION)
for (i in 1:num_permutations) {
  data_perm <- randomize_elevation(data)
  
  full.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite +
      Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot1ba <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Total Betadiversity model using Δ elevation, the interaction between TAXON and ELEVATION is", significance, "with a P-value =", p_value))
j = j+1

# Testing 2-WAY interaction: TAXON x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Total Betadiversity models randomizing Region only (TAXON x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_region(data)
  
  full.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite +
      Taxon:Alt_Dist + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot2ba <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Total Betadiversity model using Δ elevation, the interaction between TAXON and REGION is", significance, "with a P-value =", p_value))
j = j+1

# Testing 2-WAY interaction: ELEVATION x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Total Betadiversity models randomizing Elevation and Region (ELEVATION x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_elev_region(data)
  
  full.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot3ba <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Total Betadiversity model using Δ elevation, the interaction between ELEVATION and REGION is", significance, "with a P-value =", p_value))
j = j+1


# Testing 3-WAY interaction: TAXON x ELEVATION x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + Taxon:SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Total Betadiversity models randomizing Taxon, Elevation and Region (TAXON x ELEVATION x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_taxa_elev_region(data)
  
  full.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + Taxon:SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Alt_Dist + SamplingSite + 
      Taxon:Alt_Dist + Taxon:SamplingSite + SamplingSite:Alt_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot4ba <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Total Betadiversity model using Δ elevation, the interaction between TAXON x ELEVATION x REGION is", significance, "with a P-value =", p_value))
j = j+1





#### ------------------------------------------------------------------- ####


# Models including euclidean distances - statistical significance ####
#### TABLE 1: Top part of table. 
# Statistical significance of each interaction term included in the β-diversity models using region, organism group and geographical differences as explanatory variables. Values at or below 0.05 are deemed significant 

## TURNOVER ~ SamplingSite * Taxon * Spatial_Dist + (1|PlotPair)  ####

# Testing 2-WAY interaction: TAXON x EUCLIDEAN DISTANCE ####
# Real Data Models:
full.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced turnover models randomizing Spatial distance only (TAXON x EUCLIDEAN DISTANCE)
for (i in 1:num_permutations) {
  data_perm <- randomize_spatdist(data)
  
  full.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite +
      Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot1td <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Turnover model using Δ distance the interaction between TAXON and EUCLIDEAN DISTANCE is", significance, "with a P-value =", p_value))
j = j+1



# Testing 2-WAY interaction: TAXON x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced turnover models randomizing Region only (TAXON x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_region(data)
  
  full.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite +
      Taxon:Spatial_Dist + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot2td <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Turnover model using Δ distance the interaction between TAXON and REGION is", significance, "with a P-value =", p_value))
j = j+1

# Testing 2-WAY interaction: EUCLIDEAN DISTANCE x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced turnover models randomizing Spatial distance and Region (EUCLIDEAN DISTANCE x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_spatdist_region(data)
  
  full.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot3td <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Turnover model using Δ distance the interaction between EUCLIDEAN DISTANCE and REGION is", significance, "with a P-value =", p_value))
j = j+1


# Testing 3-WAY interaction: TAXON x EUCLIDEAN DISTANCE x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + Taxon:SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced turnover models randomizing Taxon, Spatial distance and Region (TAXON x EUCLIDEAN DISTANCE x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_taxa_spatdist_region(data)
  
  full.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + Taxon:SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Turnover_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot4td <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Turnover model using Δ distance the interaction between TAXON x EUCLIDEAN DISTANCE x REGION is", significance, "with a P-value =", p_value))
j = j+1

#### ------------------------------------------------------------------- ####

## NESTEDNESS ~ SamplingSite * Taxon * Spatial_Dist + (1|PlotPair)  ####

# Testing 2-WAY interaction: TAXON x EUCLIDEAN DISTANCE ####
# Real Data Models:
full.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Nestedness models randomizing Spatial distance only (TAXON x EUCLIDEAN DISTANCE)
for (i in 1:num_permutations) {
  data_perm <- randomize_spatdist(data)
  
  full.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite +
      Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot1nd <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Nestedness model using Δ distance the interaction between TAXON and EUCLIDEAN DISTANCE is", significance, "with a P-value =", p_value))
j = j+1



# Testing 2-WAY interaction: TAXON x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Nestedness models randomizing Region only (TAXON x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_region(data)
  
  full.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite +
      Taxon:Spatial_Dist + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot2nd <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Nestedness model using Δ distance the interaction between TAXON and REGION is", significance, "with a P-value =", p_value))
j = j+1

# Testing 2-WAY interaction: EUCLIDEAN DISTANCE x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Nestedness models randomizing Spatial distance and Region (EUCLIDEAN DISTANCE x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_spatdist_region(data)
  
  full.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot3nd <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Nestedness model using Δ distance the interaction between EUCLIDEAN DISTANCE and REGION is", significance, "with a P-value =", p_value))
j = j+1


# Testing 3-WAY interaction: TAXON x EUCLIDEAN DISTANCE x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + Taxon:SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Nestedness models randomizing Taxon, Spatial distance and Region (TAXON x EUCLIDEAN DISTANCE x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_taxa_spatdist_region(data)
  
  full.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + Taxon:SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Nestedness_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot4nd <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Nestedness model using Δ distance the interaction between TAXON x EUCLIDEAN DISTANCE x REGION is", significance, "with a P-value =", p_value))
j = j+1

#### ------------------------------------------------------------------- ####

## BETA TOTAL ~ SamplingSite * Taxon * Spatial_Dist + (1|PlotPair)  ####

# Testing 2-WAY interaction: TAXON x EUCLIDEAN DISTANCE ####
# Real Data Models:
full.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Total Betadiversity models randomizing Spatial distance only (TAXON x EUCLIDEAN DISTANCE)
for (i in 1:num_permutations) {
  data_perm <- randomize_spatdist(data)
  
  full.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite +
      Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot1bd <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Total Betadiversity model using Δ distance the interaction between TAXON and EUCLIDEAN DISTANCE is", significance, "with a P-value =", p_value))
j = j+1

# Testing 2-WAY interaction: TAXON x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Total Betadiversity models randomizing Region only (TAXON x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_region(data)
  
  full.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite +
      Taxon:Spatial_Dist + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot2bd <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Total Betadiversity model using Δ distance the interaction between TAXON and REGION is", significance, "with a P-value =", p_value))
j = j+1

# Testing 2-WAY interaction: EUCLIDEAN DISTANCE x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Total Betadiversity models randomizing Spatial distance and Region (EUCLIDEAN DISTANCE x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_spatdist_region(data)
  
  full.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot3bd <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Total Betadiversity model using Δ distance the interaction between EUCLIDEAN DISTANCE and REGION is", significance, "with a P-value =", p_value))
j = j+1


# Testing 3-WAY interaction: TAXON x EUCLIDEAN DISTANCE x REGION ####
# Real Data Models:
full.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + Taxon:SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(full.model)

red.model <-
  glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data,
    family = gaussian())
summary(red.model)

loglik_real<-as.numeric(2*(logLik(full.model)-logLik(red.model)))
library(lmtest)
lrtest(full.model, red.model)

# Number of permutations
num_permutations <- 1000

# Vector to store permuted loglikelihood ratios
loglik_perm <- numeric(num_permutations)

# Run full vs reduced Total Betadiversity models randomizing Taxon, Spatial distance and Region (TAXON x EUCLIDEAN DISTANCE x REGION)
for (i in 1:num_permutations) {
  data_perm <- randomize_taxa_spatdist_region(data)
  
  full.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + Taxon:SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  red.model.perm <- glmmTMB(
    Btotal_logit ~ Taxon + Spatial_Dist + SamplingSite + 
      Taxon:Spatial_Dist + Taxon:SamplingSite + SamplingSite:Spatial_Dist + (1|PlotPair),
    data = data_perm,
    family = gaussian()
  )
  # Store the logLik ratio for each permutation
  loglik_perm[i] <- as.numeric(2*(logLik(full.model.perm)-logLik(red.model.perm)))
  
}

# Plot density of permuted Loglik ratios with the real Loglik ratio as a line.
dataloglik<- data.frame(loglik_perm,rep(loglik_real, 1000))
colnames(dataloglik)[2] <- "loglik_real"

plot4bd <- ggplot(dataloglik, aes(x = loglik_perm)) +
  geom_density() +
  geom_vline(xintercept = loglik_real, color = "red", linetype = "dashed") +
  labs(x = "Log-Likelihood", 
       y = "Density", 
       title = "Density Plot of Permuted Log-Likelihood Ratios")

# Calculate the proportion of permuted loglikelihood ratios that are more extreme than the observed loglikelihood ratio
p_value <- sum(loglik_perm >= loglik_real) / num_permutations

# Determine significance level (e.g., alpha = 0.05)
if (p_value <= 0.05) {
  significance <- "significant"
} else {
  significance <- "not significant"
}

# Print results
results[j,2]<-print(paste("For the Total Betadiversity model using Δ distance the interaction between TAXON x EUCLIDEAN DISTANCE x REGION is", significance, "with a P-value =", p_value))


#### ------------------------------------------------------------------- ####

#########################################################################################
# β-diversity: Community dissimilarity among organism groups within and between regions #
#########################################################################################
#### FIGURE 5: Community dissimilarity among organism groups within and between regions. Following Baselga & Orme (2012), we partition overall dissimilarity into its turnover and nestedness components. Shown in each panel is the overall distribution of pairwise community dissimilarity values between each pair of sampling sites (for each group of organisms) within (hollow–filled violin plots) and between regions (colour–filled violin plots).

# Importing dataset
KV_total <- read.csv("//path-to-data/beta_within_between_regions.csv", sep=";")
# Betadiversity raw values plotted using violing plots ####
# Turnover
Jtur_KV <- KV_total %>%
  mutate(Taxon = fct_relevel(Taxon, "Fungi", "Plant", "Pitfall", "Malaise")) %>%
  ggplot(., aes(Taxon, y = Turnover, color = Taxon)) +
  geom_violin(aes(fill = Taxon), alpha = .7) +
  geom_violin(data = VK_total, aes(), alpha = .4) +
  scale_fill_manual(values = c("#650B67","#FFCA2A","#2A97F7","#FD6524")) +
  scale_color_manual(values = c("#650B67","#FFCA2A","#2A97F7","#FD6524")) +
  ylab(expression(Turnover ~ (J[tur]))) +
  xlab(expression("")) +
  scale_y_continuous(limits = c(0,1)) +
  theme_classic(base_size = 22, base_family = "serif") +
  theme(axis.text = element_text(size = 16, colour = "black"),
        axis.title = element_text(size = 16, colour = "black"),
        panel.grid.major = element_line(colour = "grey70", linewidth = 0.2),
        panel.grid.minor = element_blank(),
        legend.position = "none")
# Nestedness
Jnes_KV <- KV_total %>%
  mutate(Taxon = fct_relevel(Taxon, "Fungi", "Plant", "Pitfall", "Malaise")) %>%
  ggplot(., aes(Taxon, y = Nestedness, color = Taxon)) +
  geom_violin(aes(fill = Taxon), alpha = .7) +
  geom_violin(data = VK_total, aes(), alpha = .4) +
  scale_fill_manual(values = c("#650B67","#FFCA2A","#2A97F7","#FD6524")) +
  scale_color_manual(values = c("#650B67","#FFCA2A","#2A97F7","#FD6524")) +
  ylab(expression(Nestedness ~ (J[nes]))) +
  xlab(expression("")) +
  scale_y_continuous(limits = c(0,1)) +
  theme_classic(base_size = 22, base_family = "serif") +
  theme(axis.text = element_text(size = 16, colour = "black"),
        axis.title = element_text(size = 16, colour = "black"),
        panel.grid.major = element_line(colour = "grey70", linewidth = 0.2),
        panel.grid.minor = element_blank(),
        legend.position = "none")
# Total Betadiversity
Jtot_KV <- KV_total %>%
  mutate(Taxon = fct_relevel(Taxon, "Fungi", "Plant", "Pitfall", "Malaise")) %>%
  ggplot(., aes(Taxon, y = Btot, color = Taxon)) +
  geom_violin(aes(fill = Taxon), alpha = .7) +
  geom_violin(data = VK_total, aes(), alpha = .4) +
  scale_fill_manual(values = c("#650B67","#FFCA2A","#2A97F7","#FD6524")) +
  scale_color_manual(values = c("#650B67","#FFCA2A","#2A97F7","#FD6524")) +
  ylab(expression(Total ~ Betadiversity ~ (J[tot]))) +
  xlab(expression("")) +
  scale_y_continuous(limits = c(0,1)) +
  theme_classic(base_size = 22, base_family = "serif") +
  theme(axis.text = element_text(size = 16, colour = "black"),
        axis.title = element_text(size = 16, colour = "black"),
        panel.grid.major = element_line(colour = "grey70", linewidth = 0.2),
        panel.grid.minor = element_blank(),
        legend.position = "none")
# Total Plots ####
total_violins<-ggarrange(
  Jtur_KV,Jnes_KV,Jtot_KV,
  nrow = 1,
  ncol = 3, common.legend = F)


#### ------------------------------------------------------------------- ####

#############################################################################
# β-diversity: Community dissimilarity among organism groups within regions #
#############################################################################
#### FIGURE 6: Following Baselga & Orme (2012), we partition overall dissimilarity into its turnover and nestedness components. Shown in each panel are the fitted slopes of pairwise community dissimilarity between each pair of sampling sites (for each group of organisms, shown on the logit-scale), against standardized pairwise distances along the elevational and geographic axes. Shown on the right side of each panel are the marginal distribution of each organism group values

# Note: This part runs on the models built earlier in the script.
# Turnover effects ~ SamplingSite * Taxon * Alt_Dist + (1|PlotPair) ####
# Plotting Effects Altitude Difference:
Jtur_k <- ggpredict(Jtur_Alt_m, 
                    terms = c("Alt_Dist", "Taxon", "SamplingSite[Kilpisjarvi]")) |>
  plot() + 
  scale_fill_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  scale_color_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  xlim(-2, 4) + 
  ylim(-1.5, 3) + 
  labs(title = NULL) +
  xlab(expression("")) +
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_text(size = 16, colour = "black"),
        legend.position = "none") + 
  ylab(expression(Logit ~ (Turnover ~ (J[tur]))))

Jtur_densK <- ggplot(subset(VK_total_trans, SamplingSite == "Kilpisjarvi"),
                     aes(x = Turnover_logit, fill = Taxon)) + 
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_density(alpha = 0.3) +
  theme_void() +
  theme(legend.position = "none") + coord_flip()

Jtur_v <- ggpredict(Jtur_Alt_m,
                    terms = c("Alt_Dist", "Taxon", "SamplingSite[Varanger]")) |>
  plot() + 
  scale_fill_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  scale_color_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  xlim(-2, 4) + 
  ylim(-1.5, 3) + 
  labs(title = NULL) + 
  xlab(expression("")) +
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_blank(),
        legend.position = "none")
Jtur_densV <- ggplot(subset(VK_total_trans, SamplingSite == "Varanger"),
                     aes(x = Turnover_logit, fill = Taxon)) +
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_density(alpha = 0.3) +
  theme_void() +
  theme(legend.position = "none") + coord_flip()

# Plotting Effects Spatial distance:
Jtur_k_sd <- ggpredict(Jtur_Spatial_m, 
                       terms = c("Spatial_Dist", "Taxon", "SamplingSite[Kilpisjarvi]")) |>
  plot() + 
  scale_fill_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  scale_color_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  xlim(-2, 4) + 
  ylim(-1.5, 3) + 
  labs(title = NULL) + 
  xlab(expression("")) +
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_text(size = 16, colour = "black"),
        axis.title.y = element_blank(),
        legend.position = "none")

Jtur_densK_sd <- ggplot(subset(VK_total_trans, SamplingSite == "Kilpisjarvi"), 
                        aes(x = Turnover_logit, fill = Taxon)) + 
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_density(alpha = 0.3) + 
  theme_void() + 
  theme(legend.position = "none") + coord_flip()

Jtur_v_sd <-
  ggpredict(Jtur_Spatial_m, 
            terms = c("Spatial_Dist", "Taxon", "SamplingSite[Varanger]")) |> 
  plot() + 
  scale_fill_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  scale_color_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  xlim(-2, 4) + 
  ylim(-1.5, 3) + 
  labs(title = NULL) +
  xlab(expression("")) +
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_blank(),
        legend.position = "none")
Jtur_densV_sd <- ggplot(subset(VK_total_trans, SamplingSite == "Varanger"), 
                        aes(x = Turnover_logit, fill = Taxon)) + 
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_density(alpha = 0.3) + 
  theme_void() + 
  theme(legend.position = "none") + coord_flip()

# Final Plot:
uno<-Jtur_k + Jtur_densK + Jtur_v + Jtur_densV + 
  Jtur_k_sd + Jtur_densK_sd + Jtur_v_sd + Jtur_densV_sd +
  plot_layout(ncol = 8, nrow = 1,
              widths = c(30, 5, 30, 5, 30, 5, 30, 5),
              heights = c(5, 30, 5, 30, 5, 30, 5, 30))

# Nestedness effects ~ SamplingSite * Taxon * Alt_Dist + (1|PlotPair) ####
# Plotting Effects Altitude Difference:
Jnes_k <- ggpredict(Jnes_Alt_m, 
                    terms = c("Alt_Dist", "Taxon", "SamplingSite[Kilpisjarvi]")) |>
  plot() + 
  scale_fill_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  scale_color_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  xlim(-2, 4) + 
  ylim(-5, 0) + 
  labs(title = NULL) +
  xlab(expression("")) +
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_text(size = 16, colour = "black"),
        legend.position = "none") + 
  ylab(expression(Logit ~ (Nestedness ~ (J[nes]))))

Jnes_densK <- ggplot(subset(VK_total_trans, SamplingSite == "Kilpisjarvi"),
                     aes(x = Nestedness_logit, fill = Taxon)) + 
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_density(alpha = 0.3) +
  theme_void() +
  theme(legend.position = "none") + coord_flip()

Jnes_v <- ggpredict(Jnes_Alt_m,
                    terms = c("Alt_Dist", "Taxon", "SamplingSite[Varanger]")) |>
  plot() + 
  scale_fill_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  scale_color_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  xlim(-2, 4) + 
  ylim(-5, 0) + 
  labs(title = NULL) + 
  xlab(expression("")) +
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_blank(),
        legend.position = "none")
Jnes_densV <- ggplot(subset(VK_total_trans, SamplingSite == "Varanger"),
                     aes(x = Nestedness_logit, fill = Taxon)) +
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_density(alpha = 0.3) +
  theme_void() +
  theme(legend.position = "none") + coord_flip()

# Plotting Effects Spatial distance:
Jnes_k_sd <- ggpredict(Jnes_Spatial_m, 
                       terms = c("Spatial_Dist", "Taxon", "SamplingSite[Kilpisjarvi]")) |>
  plot() + 
  scale_fill_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  scale_color_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  xlim(-2, 4) + 
  ylim(-5, 0) + 
  labs(title = NULL) + 
  xlab(expression("")) +
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_text(size = 16, colour = "black"),
        axis.title.y = element_blank(),
        legend.position = "none")

Jnes_densK_sd <- ggplot(subset(VK_total_trans, SamplingSite == "Kilpisjarvi"), 
                        aes(x = Nestedness_logit, fill = Taxon)) + 
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_density(alpha = 0.3) + 
  theme_void() + 
  theme(legend.position = "none") + coord_flip()

Jnes_v_sd <-
  ggpredict(Jnes_Spatial_m, 
            terms = c("Spatial_Dist", "Taxon", "SamplingSite[Varanger]")) |> 
  plot() + 
  scale_fill_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  scale_color_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  xlim(-2, 4) + 
  ylim(-5, 0) + 
  labs(title = NULL) +
  xlab(expression("")) +
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_blank(),
        legend.position = "none")
Jnes_densV_sd <- ggplot(subset(VK_total_trans, SamplingSite == "Varanger"), 
                        aes(x = Nestedness_logit, fill = Taxon)) + 
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_density(alpha = 0.3) + 
  theme_void() + 
  theme(legend.position = "none") + coord_flip()

# Final Plot:
dos<-Jnes_k + Jnes_densK + Jnes_v + Jnes_densV + 
  Jnes_k_sd + Jnes_densK_sd + Jnes_v_sd + Jnes_densV_sd +
  plot_layout(ncol = 8, nrow = 1,
              widths = c(30, 5, 30, 5, 30, 5, 30, 5),
              heights = c(5, 30, 5, 30, 5, 30, 5, 30))

# Total betadiversity effects ~ SamplingSite * Taxon * Alt_Dist + (1|PlotPair) ####
# Plotting Effects Altitude Difference:
Jtot_k <- ggpredict(Jtot_Alt_m, 
                    terms = c("Alt_Dist", "Taxon", "SamplingSite[Kilpisjarvi]")) |>
  plot() + 
  scale_fill_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  scale_color_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  xlim(-2, 4) + 
  ylim(-1, 4) + 
  labs(title = NULL) +
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_text(size = 16, colour = "black"),
        legend.position = "none") + 
  xlab("Std Elevational Difference") +
  ylab(expression(Logit ~ (Total ~ Betadiversity ~ (J[tot]))))

Jtot_densK <- ggplot(subset(VK_total_trans, SamplingSite == "Kilpisjarvi"),
                     aes(x = Btotal_logit, fill = Taxon)) + 
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_density(alpha = 0.3) +
  theme_void() +
  theme(legend.position = "none") + coord_flip()

Jtot_v <- ggpredict(Jtot_Alt_m,
                    terms = c("Alt_Dist", "Taxon", "SamplingSite[Varanger]")) |>
  plot() + 
  scale_fill_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  scale_color_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  xlim(-2, 4) + 
  ylim(-1, 4) + 
  labs(title = NULL) + 
  xlab(expression("")) +
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_blank(),
        legend.position = "none")
Jtot_densV <- ggplot(subset(VK_total_trans, SamplingSite == "Varanger"),
                     aes(x = Btotal_logit, fill = Taxon)) +
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_density(alpha = 0.3) +
  theme_void() +
  theme(legend.position = "none") + coord_flip()

# Plotting Effects Spatial distance:
Jtot_k_sd <- ggpredict(Jtot_Spatial_m, 
                       terms = c("Spatial_Dist", "Taxon", "SamplingSite[Kilpisjarvi]")) |>
  plot() + 
  scale_fill_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  scale_color_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  xlim(-2, 4) + 
  ylim(-1, 4) + 
  labs(title = NULL) + 
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_text(size = 16, colour = "black"),
        axis.title.y = element_blank(),
        legend.position = "none") +
  xlab("Std Euclidean Distance")

Jtot_densK_sd <- ggplot(subset(VK_total_trans, SamplingSite == "Kilpisjarvi"), 
                        aes(x = Btotal_logit, fill = Taxon)) + 
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_density(alpha = 0.3) + 
  theme_void() + 
  theme(legend.position = "none") + coord_flip()

Jtot_v_sd <-
  ggpredict(Jtot_Spatial_m, 
            terms = c("Spatial_Dist", "Taxon", "SamplingSite[Varanger]")) |> 
  plot() + 
  scale_fill_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  scale_color_manual(values = c("#FD6524","#2A97F7","#FFCA2A","#650B67")) +
  xlim(-2, 4) + 
  ylim(-1, 4) + 
  labs(title = NULL) +
  xlab(expression("")) +
  theme(text = element_text(family = "serif"),
        axis.text = element_text(size = 16, colour = "black"),
        strip.text.x = element_text(size = 16, colour = "black"),
        axis.title = element_blank(),
        legend.position = "none")
Jtot_densV_sd <- ggplot(subset(VK_total_trans, SamplingSite == "Varanger"), 
                        aes(x = Btotal_logit, fill = Taxon)) + 
  scale_fill_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  scale_color_manual(values = c("#650B67","#FD6524","#2A97F7","#FFCA2A")) +
  geom_density(alpha = 0.3) + 
  theme_void() + 
  theme(legend.position = "none") + coord_flip()

# Final Plot:
tres<-Jtot_k + Jtot_densK + Jtot_v + Jtot_densV + 
  Jtot_k_sd + Jtot_densK_sd + Jtot_v_sd + Jtot_densV_sd +
  plot_layout(ncol = 8, nrow = 1,
              widths = c(30, 5, 30, 5, 30, 5, 30, 5),
              heights = c(5, 30, 5, 30, 5, 30, 5, 30))
# Total Plots ####
ggarrange(uno,dos,tres, ncol = 1, nrow = 3)

#### ------------------------------------------------------------------- ####

#### ---------------------------------------------------------------------- ####
#### ---------------------------------------------------------------------- ####
#### -------------------------------- END --------------------------------- ####
#### ---------------------------------------------------------------------- ####
#### ---------------------------------------------------------------------- ####

